/*******************************************************************************
* File Name: NeoClock.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_NeoClock_H)
#define CY_CLOCK_NeoClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void NeoClock_StartEx(uint32 alignClkDiv);
#define NeoClock_Start() \
    NeoClock_StartEx(NeoClock__PA_DIV_ID)

#else

void NeoClock_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void NeoClock_Stop(void);

void NeoClock_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 NeoClock_GetDividerRegister(void);
uint8  NeoClock_GetFractionalDividerRegister(void);

#define NeoClock_Enable()                         NeoClock_Start()
#define NeoClock_Disable()                        NeoClock_Stop()
#define NeoClock_SetDividerRegister(clkDivider, reset)  \
    NeoClock_SetFractionalDividerRegister((clkDivider), 0u)
#define NeoClock_SetDivider(clkDivider)           NeoClock_SetDividerRegister((clkDivider), 1u)
#define NeoClock_SetDividerValue(clkDivider)      NeoClock_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define NeoClock_DIV_ID     NeoClock__DIV_ID

#define NeoClock_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define NeoClock_CTRL_REG   (*(reg32 *)NeoClock__CTRL_REGISTER)
#define NeoClock_DIV_REG    (*(reg32 *)NeoClock__DIV_REGISTER)

#define NeoClock_CMD_DIV_SHIFT          (0u)
#define NeoClock_CMD_PA_DIV_SHIFT       (8u)
#define NeoClock_CMD_DISABLE_SHIFT      (30u)
#define NeoClock_CMD_ENABLE_SHIFT       (31u)

#define NeoClock_CMD_DISABLE_MASK       ((uint32)((uint32)1u << NeoClock_CMD_DISABLE_SHIFT))
#define NeoClock_CMD_ENABLE_MASK        ((uint32)((uint32)1u << NeoClock_CMD_ENABLE_SHIFT))

#define NeoClock_DIV_FRAC_MASK  (0x000000F8u)
#define NeoClock_DIV_FRAC_SHIFT (3u)
#define NeoClock_DIV_INT_MASK   (0xFFFFFF00u)
#define NeoClock_DIV_INT_SHIFT  (8u)

#else 

#define NeoClock_DIV_REG        (*(reg32 *)NeoClock__REGISTER)
#define NeoClock_ENABLE_REG     NeoClock_DIV_REG
#define NeoClock_DIV_FRAC_MASK  NeoClock__FRAC_MASK
#define NeoClock_DIV_FRAC_SHIFT (16u)
#define NeoClock_DIV_INT_MASK   NeoClock__DIVIDER_MASK
#define NeoClock_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_NeoClock_H) */

/* [] END OF FILE */
