/*******************************************************************************
* File Name: State0.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "State0.h"

static State0_BACKUP_STRUCT  State0_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: State0_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function applies only to SIO and USBIO pins.
*  It should not be called for GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet State0_SUT.c usage_State0_Sleep_Wakeup
*******************************************************************************/
void State0_Sleep(void)
{
    #if defined(State0__PC)
        State0_backup.pcState = State0_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            State0_backup.usbState = State0_CR1_REG;
            State0_USB_POWER_REG |= State0_USBIO_ENTER_SLEEP;
            State0_CR1_REG &= State0_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(State0__SIO)
        State0_backup.sioState = State0_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        State0_SIO_REG &= (uint32)(~State0_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: State0_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep(). This 
* function applies only to SIO and USBIO pins. It should not be called for
* GPIO or GPIO_OVT pins.
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to State0_Sleep() for an example usage.
*******************************************************************************/
void State0_Wakeup(void)
{
    #if defined(State0__PC)
        State0_PC = State0_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            State0_USB_POWER_REG &= State0_USBIO_EXIT_SLEEP_PH1;
            State0_CR1_REG = State0_backup.usbState;
            State0_USB_POWER_REG &= State0_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(State0__SIO)
        State0_SIO_REG = State0_backup.sioState;
    #endif
}


/* [] END OF FILE */
