/*******************************************************************************
* File Name: TimerPWM.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the TimerPWM
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_TimerPWM_H)
#define CY_TCPWM_TimerPWM_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} TimerPWM_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  TimerPWM_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define TimerPWM_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define TimerPWM_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define TimerPWM_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define TimerPWM_QUAD_ENCODING_MODES            (0lu)
#define TimerPWM_QUAD_AUTO_START                (0lu)

/* Signal modes */
#define TimerPWM_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define TimerPWM_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define TimerPWM_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define TimerPWM_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define TimerPWM_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define TimerPWM_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define TimerPWM_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define TimerPWM_TC_RUN_MODE                    (0lu)
#define TimerPWM_TC_COUNTER_MODE                (0lu)
#define TimerPWM_TC_COMP_CAP_MODE               (2lu)
#define TimerPWM_TC_PRESCALER                   (0lu)

/* Signal modes */
#define TimerPWM_TC_RELOAD_SIGNAL_MODE          (0lu)
#define TimerPWM_TC_COUNT_SIGNAL_MODE           (3lu)
#define TimerPWM_TC_START_SIGNAL_MODE           (0lu)
#define TimerPWM_TC_STOP_SIGNAL_MODE            (0lu)
#define TimerPWM_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define TimerPWM_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define TimerPWM_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define TimerPWM_TC_START_SIGNAL_PRESENT        (0lu)
#define TimerPWM_TC_STOP_SIGNAL_PRESENT         (0lu)
#define TimerPWM_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define TimerPWM_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define TimerPWM_PWM_KILL_EVENT                 (0lu)
#define TimerPWM_PWM_STOP_EVENT                 (0lu)
#define TimerPWM_PWM_MODE                       (4lu)
#define TimerPWM_PWM_OUT_N_INVERT               (0lu)
#define TimerPWM_PWM_OUT_INVERT                 (0lu)
#define TimerPWM_PWM_ALIGN                      (0lu)
#define TimerPWM_PWM_RUN_MODE                   (0lu)
#define TimerPWM_PWM_DEAD_TIME_CYCLE            (0lu)
#define TimerPWM_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define TimerPWM_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define TimerPWM_PWM_COUNT_SIGNAL_MODE          (3lu)
#define TimerPWM_PWM_START_SIGNAL_MODE          (0lu)
#define TimerPWM_PWM_STOP_SIGNAL_MODE           (0lu)
#define TimerPWM_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define TimerPWM_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define TimerPWM_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define TimerPWM_PWM_START_SIGNAL_PRESENT       (0lu)
#define TimerPWM_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define TimerPWM_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define TimerPWM_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define TimerPWM_TC_PERIOD_VALUE                (999lu)
#define TimerPWM_TC_COMPARE_VALUE               (65535lu)
#define TimerPWM_TC_COMPARE_BUF_VALUE           (65535lu)
#define TimerPWM_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define TimerPWM_PWM_PERIOD_VALUE               (65535lu)
#define TimerPWM_PWM_PERIOD_BUF_VALUE           (65535lu)
#define TimerPWM_PWM_PERIOD_SWAP                (0lu)
#define TimerPWM_PWM_COMPARE_VALUE              (65535lu)
#define TimerPWM_PWM_COMPARE_BUF_VALUE          (65535lu)
#define TimerPWM_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define TimerPWM__LEFT 0
#define TimerPWM__RIGHT 1
#define TimerPWM__CENTER 2
#define TimerPWM__ASYMMETRIC 3

#define TimerPWM__X1 0
#define TimerPWM__X2 1
#define TimerPWM__X4 2

#define TimerPWM__PWM 4
#define TimerPWM__PWM_DT 5
#define TimerPWM__PWM_PR 6

#define TimerPWM__INVERSE 1
#define TimerPWM__DIRECT 0

#define TimerPWM__CAPTURE 2
#define TimerPWM__COMPARE 0

#define TimerPWM__TRIG_LEVEL 3
#define TimerPWM__TRIG_RISING 0
#define TimerPWM__TRIG_FALLING 1
#define TimerPWM__TRIG_BOTH 2

#define TimerPWM__INTR_MASK_TC 1
#define TimerPWM__INTR_MASK_CC_MATCH 2
#define TimerPWM__INTR_MASK_NONE 0
#define TimerPWM__INTR_MASK_TC_CC 3

#define TimerPWM__UNCONFIG 8
#define TimerPWM__TIMER 1
#define TimerPWM__QUAD 3
#define TimerPWM__PWM_SEL 7

#define TimerPWM__COUNT_UP 0
#define TimerPWM__COUNT_DOWN 1
#define TimerPWM__COUNT_UPDOWN0 2
#define TimerPWM__COUNT_UPDOWN1 3


/* Prescaler */
#define TimerPWM_PRESCALE_DIVBY1                ((uint32)(0u << TimerPWM_PRESCALER_SHIFT))
#define TimerPWM_PRESCALE_DIVBY2                ((uint32)(1u << TimerPWM_PRESCALER_SHIFT))
#define TimerPWM_PRESCALE_DIVBY4                ((uint32)(2u << TimerPWM_PRESCALER_SHIFT))
#define TimerPWM_PRESCALE_DIVBY8                ((uint32)(3u << TimerPWM_PRESCALER_SHIFT))
#define TimerPWM_PRESCALE_DIVBY16               ((uint32)(4u << TimerPWM_PRESCALER_SHIFT))
#define TimerPWM_PRESCALE_DIVBY32               ((uint32)(5u << TimerPWM_PRESCALER_SHIFT))
#define TimerPWM_PRESCALE_DIVBY64               ((uint32)(6u << TimerPWM_PRESCALER_SHIFT))
#define TimerPWM_PRESCALE_DIVBY128              ((uint32)(7u << TimerPWM_PRESCALER_SHIFT))

/* TCPWM set modes */
#define TimerPWM_MODE_TIMER_COMPARE             ((uint32)(TimerPWM__COMPARE         <<  \
                                                                  TimerPWM_MODE_SHIFT))
#define TimerPWM_MODE_TIMER_CAPTURE             ((uint32)(TimerPWM__CAPTURE         <<  \
                                                                  TimerPWM_MODE_SHIFT))
#define TimerPWM_MODE_QUAD                      ((uint32)(TimerPWM__QUAD            <<  \
                                                                  TimerPWM_MODE_SHIFT))
#define TimerPWM_MODE_PWM                       ((uint32)(TimerPWM__PWM             <<  \
                                                                  TimerPWM_MODE_SHIFT))
#define TimerPWM_MODE_PWM_DT                    ((uint32)(TimerPWM__PWM_DT          <<  \
                                                                  TimerPWM_MODE_SHIFT))
#define TimerPWM_MODE_PWM_PR                    ((uint32)(TimerPWM__PWM_PR          <<  \
                                                                  TimerPWM_MODE_SHIFT))

/* Quad Modes */
#define TimerPWM_MODE_X1                        ((uint32)(TimerPWM__X1              <<  \
                                                                  TimerPWM_QUAD_MODE_SHIFT))
#define TimerPWM_MODE_X2                        ((uint32)(TimerPWM__X2              <<  \
                                                                  TimerPWM_QUAD_MODE_SHIFT))
#define TimerPWM_MODE_X4                        ((uint32)(TimerPWM__X4              <<  \
                                                                  TimerPWM_QUAD_MODE_SHIFT))

/* Counter modes */
#define TimerPWM_COUNT_UP                       ((uint32)(TimerPWM__COUNT_UP        <<  \
                                                                  TimerPWM_UPDOWN_SHIFT))
#define TimerPWM_COUNT_DOWN                     ((uint32)(TimerPWM__COUNT_DOWN      <<  \
                                                                  TimerPWM_UPDOWN_SHIFT))
#define TimerPWM_COUNT_UPDOWN0                  ((uint32)(TimerPWM__COUNT_UPDOWN0   <<  \
                                                                  TimerPWM_UPDOWN_SHIFT))
#define TimerPWM_COUNT_UPDOWN1                  ((uint32)(TimerPWM__COUNT_UPDOWN1   <<  \
                                                                  TimerPWM_UPDOWN_SHIFT))

/* PWM output invert */
#define TimerPWM_INVERT_LINE                    ((uint32)(TimerPWM__INVERSE         <<  \
                                                                  TimerPWM_INV_OUT_SHIFT))
#define TimerPWM_INVERT_LINE_N                  ((uint32)(TimerPWM__INVERSE         <<  \
                                                                  TimerPWM_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define TimerPWM_TRIG_RISING                    ((uint32)TimerPWM__TRIG_RISING)
#define TimerPWM_TRIG_FALLING                   ((uint32)TimerPWM__TRIG_FALLING)
#define TimerPWM_TRIG_BOTH                      ((uint32)TimerPWM__TRIG_BOTH)
#define TimerPWM_TRIG_LEVEL                     ((uint32)TimerPWM__TRIG_LEVEL)

/* Interrupt mask */
#define TimerPWM_INTR_MASK_TC                   ((uint32)TimerPWM__INTR_MASK_TC)
#define TimerPWM_INTR_MASK_CC_MATCH             ((uint32)TimerPWM__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define TimerPWM_CC_MATCH_SET                   (0x00u)
#define TimerPWM_CC_MATCH_CLEAR                 (0x01u)
#define TimerPWM_CC_MATCH_INVERT                (0x02u)
#define TimerPWM_CC_MATCH_NO_CHANGE             (0x03u)
#define TimerPWM_OVERLOW_SET                    (0x00u)
#define TimerPWM_OVERLOW_CLEAR                  (0x04u)
#define TimerPWM_OVERLOW_INVERT                 (0x08u)
#define TimerPWM_OVERLOW_NO_CHANGE              (0x0Cu)
#define TimerPWM_UNDERFLOW_SET                  (0x00u)
#define TimerPWM_UNDERFLOW_CLEAR                (0x10u)
#define TimerPWM_UNDERFLOW_INVERT               (0x20u)
#define TimerPWM_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define TimerPWM_PWM_MODE_LEFT                  (TimerPWM_CC_MATCH_CLEAR        |   \
                                                         TimerPWM_OVERLOW_SET           |   \
                                                         TimerPWM_UNDERFLOW_NO_CHANGE)
#define TimerPWM_PWM_MODE_RIGHT                 (TimerPWM_CC_MATCH_SET          |   \
                                                         TimerPWM_OVERLOW_NO_CHANGE     |   \
                                                         TimerPWM_UNDERFLOW_CLEAR)
#define TimerPWM_PWM_MODE_ASYM                  (TimerPWM_CC_MATCH_INVERT       |   \
                                                         TimerPWM_OVERLOW_SET           |   \
                                                         TimerPWM_UNDERFLOW_CLEAR)

#if (TimerPWM_CY_TCPWM_V2)
    #if(TimerPWM_CY_TCPWM_4000)
        #define TimerPWM_PWM_MODE_CENTER                (TimerPWM_CC_MATCH_INVERT       |   \
                                                                 TimerPWM_OVERLOW_NO_CHANGE     |   \
                                                                 TimerPWM_UNDERFLOW_CLEAR)
    #else
        #define TimerPWM_PWM_MODE_CENTER                (TimerPWM_CC_MATCH_INVERT       |   \
                                                                 TimerPWM_OVERLOW_SET           |   \
                                                                 TimerPWM_UNDERFLOW_CLEAR)
    #endif /* (TimerPWM_CY_TCPWM_4000) */
#else
    #define TimerPWM_PWM_MODE_CENTER                (TimerPWM_CC_MATCH_INVERT       |   \
                                                             TimerPWM_OVERLOW_NO_CHANGE     |   \
                                                             TimerPWM_UNDERFLOW_CLEAR)
#endif /* (TimerPWM_CY_TCPWM_NEW) */

/* Command operations without condition */
#define TimerPWM_CMD_CAPTURE                    (0u)
#define TimerPWM_CMD_RELOAD                     (8u)
#define TimerPWM_CMD_STOP                       (16u)
#define TimerPWM_CMD_START                      (24u)

/* Status */
#define TimerPWM_STATUS_DOWN                    (1u)
#define TimerPWM_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   TimerPWM_Init(void);
void   TimerPWM_Enable(void);
void   TimerPWM_Start(void);
void   TimerPWM_Stop(void);

void   TimerPWM_SetMode(uint32 mode);
void   TimerPWM_SetCounterMode(uint32 counterMode);
void   TimerPWM_SetPWMMode(uint32 modeMask);
void   TimerPWM_SetQDMode(uint32 qdMode);

void   TimerPWM_SetPrescaler(uint32 prescaler);
void   TimerPWM_TriggerCommand(uint32 mask, uint32 command);
void   TimerPWM_SetOneShot(uint32 oneShotEnable);
uint32 TimerPWM_ReadStatus(void);

void   TimerPWM_SetPWMSyncKill(uint32 syncKillEnable);
void   TimerPWM_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   TimerPWM_SetPWMDeadTime(uint32 deadTime);
void   TimerPWM_SetPWMInvert(uint32 mask);

void   TimerPWM_SetInterruptMode(uint32 interruptMask);
uint32 TimerPWM_GetInterruptSourceMasked(void);
uint32 TimerPWM_GetInterruptSource(void);
void   TimerPWM_ClearInterrupt(uint32 interruptMask);
void   TimerPWM_SetInterrupt(uint32 interruptMask);

void   TimerPWM_WriteCounter(uint32 count);
uint32 TimerPWM_ReadCounter(void);

uint32 TimerPWM_ReadCapture(void);
uint32 TimerPWM_ReadCaptureBuf(void);

void   TimerPWM_WritePeriod(uint32 period);
uint32 TimerPWM_ReadPeriod(void);
void   TimerPWM_WritePeriodBuf(uint32 periodBuf);
uint32 TimerPWM_ReadPeriodBuf(void);

void   TimerPWM_WriteCompare(uint32 compare);
uint32 TimerPWM_ReadCompare(void);
void   TimerPWM_WriteCompareBuf(uint32 compareBuf);
uint32 TimerPWM_ReadCompareBuf(void);

void   TimerPWM_SetPeriodSwap(uint32 swapEnable);
void   TimerPWM_SetCompareSwap(uint32 swapEnable);

void   TimerPWM_SetCaptureMode(uint32 triggerMode);
void   TimerPWM_SetReloadMode(uint32 triggerMode);
void   TimerPWM_SetStartMode(uint32 triggerMode);
void   TimerPWM_SetStopMode(uint32 triggerMode);
void   TimerPWM_SetCountMode(uint32 triggerMode);

void   TimerPWM_SaveConfig(void);
void   TimerPWM_RestoreConfig(void);
void   TimerPWM_Sleep(void);
void   TimerPWM_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define TimerPWM_BLOCK_CONTROL_REG              (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define TimerPWM_BLOCK_CONTROL_PTR              ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define TimerPWM_COMMAND_REG                    (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define TimerPWM_COMMAND_PTR                    ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define TimerPWM_INTRRUPT_CAUSE_REG             (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define TimerPWM_INTRRUPT_CAUSE_PTR             ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define TimerPWM_CONTROL_REG                    (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__CTRL )
#define TimerPWM_CONTROL_PTR                    ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__CTRL )
#define TimerPWM_STATUS_REG                     (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__STATUS )
#define TimerPWM_STATUS_PTR                     ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__STATUS )
#define TimerPWM_COUNTER_REG                    (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__COUNTER )
#define TimerPWM_COUNTER_PTR                    ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__COUNTER )
#define TimerPWM_COMP_CAP_REG                   (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__CC )
#define TimerPWM_COMP_CAP_PTR                   ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__CC )
#define TimerPWM_COMP_CAP_BUF_REG               (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__CC_BUFF )
#define TimerPWM_COMP_CAP_BUF_PTR               ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__CC_BUFF )
#define TimerPWM_PERIOD_REG                     (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__PERIOD )
#define TimerPWM_PERIOD_PTR                     ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__PERIOD )
#define TimerPWM_PERIOD_BUF_REG                 (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define TimerPWM_PERIOD_BUF_PTR                 ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define TimerPWM_TRIG_CONTROL0_REG              (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define TimerPWM_TRIG_CONTROL0_PTR              ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define TimerPWM_TRIG_CONTROL1_REG              (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define TimerPWM_TRIG_CONTROL1_PTR              ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define TimerPWM_TRIG_CONTROL2_REG              (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define TimerPWM_TRIG_CONTROL2_PTR              ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define TimerPWM_INTERRUPT_REQ_REG              (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__INTR )
#define TimerPWM_INTERRUPT_REQ_PTR              ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__INTR )
#define TimerPWM_INTERRUPT_SET_REG              (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__INTR_SET )
#define TimerPWM_INTERRUPT_SET_PTR              ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__INTR_SET )
#define TimerPWM_INTERRUPT_MASK_REG             (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__INTR_MASK )
#define TimerPWM_INTERRUPT_MASK_PTR             ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__INTR_MASK )
#define TimerPWM_INTERRUPT_MASKED_REG           (*(reg32 *) TimerPWM_cy_m0s8_tcpwm_1__INTR_MASKED )
#define TimerPWM_INTERRUPT_MASKED_PTR           ( (reg32 *) TimerPWM_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define TimerPWM_MASK                           ((uint32)TimerPWM_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define TimerPWM_RELOAD_CC_SHIFT                (0u)
#define TimerPWM_RELOAD_PERIOD_SHIFT            (1u)
#define TimerPWM_PWM_SYNC_KILL_SHIFT            (2u)
#define TimerPWM_PWM_STOP_KILL_SHIFT            (3u)
#define TimerPWM_PRESCALER_SHIFT                (8u)
#define TimerPWM_UPDOWN_SHIFT                   (16u)
#define TimerPWM_ONESHOT_SHIFT                  (18u)
#define TimerPWM_QUAD_MODE_SHIFT                (20u)
#define TimerPWM_INV_OUT_SHIFT                  (20u)
#define TimerPWM_INV_COMPL_OUT_SHIFT            (21u)
#define TimerPWM_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define TimerPWM_RELOAD_CC_MASK                 ((uint32)(TimerPWM_1BIT_MASK        <<  \
                                                                            TimerPWM_RELOAD_CC_SHIFT))
#define TimerPWM_RELOAD_PERIOD_MASK             ((uint32)(TimerPWM_1BIT_MASK        <<  \
                                                                            TimerPWM_RELOAD_PERIOD_SHIFT))
#define TimerPWM_PWM_SYNC_KILL_MASK             ((uint32)(TimerPWM_1BIT_MASK        <<  \
                                                                            TimerPWM_PWM_SYNC_KILL_SHIFT))
#define TimerPWM_PWM_STOP_KILL_MASK             ((uint32)(TimerPWM_1BIT_MASK        <<  \
                                                                            TimerPWM_PWM_STOP_KILL_SHIFT))
#define TimerPWM_PRESCALER_MASK                 ((uint32)(TimerPWM_8BIT_MASK        <<  \
                                                                            TimerPWM_PRESCALER_SHIFT))
#define TimerPWM_UPDOWN_MASK                    ((uint32)(TimerPWM_2BIT_MASK        <<  \
                                                                            TimerPWM_UPDOWN_SHIFT))
#define TimerPWM_ONESHOT_MASK                   ((uint32)(TimerPWM_1BIT_MASK        <<  \
                                                                            TimerPWM_ONESHOT_SHIFT))
#define TimerPWM_QUAD_MODE_MASK                 ((uint32)(TimerPWM_3BIT_MASK        <<  \
                                                                            TimerPWM_QUAD_MODE_SHIFT))
#define TimerPWM_INV_OUT_MASK                   ((uint32)(TimerPWM_2BIT_MASK        <<  \
                                                                            TimerPWM_INV_OUT_SHIFT))
#define TimerPWM_MODE_MASK                      ((uint32)(TimerPWM_3BIT_MASK        <<  \
                                                                            TimerPWM_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define TimerPWM_CAPTURE_SHIFT                  (0u)
#define TimerPWM_COUNT_SHIFT                    (2u)
#define TimerPWM_RELOAD_SHIFT                   (4u)
#define TimerPWM_STOP_SHIFT                     (6u)
#define TimerPWM_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define TimerPWM_CAPTURE_MASK                   ((uint32)(TimerPWM_2BIT_MASK        <<  \
                                                                  TimerPWM_CAPTURE_SHIFT))
#define TimerPWM_COUNT_MASK                     ((uint32)(TimerPWM_2BIT_MASK        <<  \
                                                                  TimerPWM_COUNT_SHIFT))
#define TimerPWM_RELOAD_MASK                    ((uint32)(TimerPWM_2BIT_MASK        <<  \
                                                                  TimerPWM_RELOAD_SHIFT))
#define TimerPWM_STOP_MASK                      ((uint32)(TimerPWM_2BIT_MASK        <<  \
                                                                  TimerPWM_STOP_SHIFT))
#define TimerPWM_START_MASK                     ((uint32)(TimerPWM_2BIT_MASK        <<  \
                                                                  TimerPWM_START_SHIFT))

/* MASK */
#define TimerPWM_1BIT_MASK                      ((uint32)0x01u)
#define TimerPWM_2BIT_MASK                      ((uint32)0x03u)
#define TimerPWM_3BIT_MASK                      ((uint32)0x07u)
#define TimerPWM_6BIT_MASK                      ((uint32)0x3Fu)
#define TimerPWM_8BIT_MASK                      ((uint32)0xFFu)
#define TimerPWM_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define TimerPWM_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define TimerPWM_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(TimerPWM_QUAD_ENCODING_MODES     << TimerPWM_QUAD_MODE_SHIFT))       |\
         ((uint32)(TimerPWM_CONFIG                  << TimerPWM_MODE_SHIFT)))

#define TimerPWM_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(TimerPWM_PWM_STOP_EVENT          << TimerPWM_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(TimerPWM_PWM_OUT_INVERT          << TimerPWM_INV_OUT_SHIFT))         |\
         ((uint32)(TimerPWM_PWM_OUT_N_INVERT        << TimerPWM_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(TimerPWM_PWM_MODE                << TimerPWM_MODE_SHIFT)))

#define TimerPWM_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(TimerPWM_PWM_RUN_MODE         << TimerPWM_ONESHOT_SHIFT))
            
#define TimerPWM_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(TimerPWM_PWM_ALIGN            << TimerPWM_UPDOWN_SHIFT))

#define TimerPWM_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(TimerPWM_PWM_KILL_EVENT      << TimerPWM_PWM_SYNC_KILL_SHIFT))

#define TimerPWM_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(TimerPWM_PWM_DEAD_TIME_CYCLE  << TimerPWM_PRESCALER_SHIFT))

#define TimerPWM_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(TimerPWM_PWM_PRESCALER        << TimerPWM_PRESCALER_SHIFT))

#define TimerPWM_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(TimerPWM_TC_PRESCALER            << TimerPWM_PRESCALER_SHIFT))       |\
         ((uint32)(TimerPWM_TC_COUNTER_MODE         << TimerPWM_UPDOWN_SHIFT))          |\
         ((uint32)(TimerPWM_TC_RUN_MODE             << TimerPWM_ONESHOT_SHIFT))         |\
         ((uint32)(TimerPWM_TC_COMP_CAP_MODE        << TimerPWM_MODE_SHIFT)))
        
#define TimerPWM_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(TimerPWM_QUAD_PHIA_SIGNAL_MODE   << TimerPWM_COUNT_SHIFT))           |\
         ((uint32)(TimerPWM_QUAD_INDEX_SIGNAL_MODE  << TimerPWM_RELOAD_SHIFT))          |\
         ((uint32)(TimerPWM_QUAD_STOP_SIGNAL_MODE   << TimerPWM_STOP_SHIFT))            |\
         ((uint32)(TimerPWM_QUAD_PHIB_SIGNAL_MODE   << TimerPWM_START_SHIFT)))

#define TimerPWM_PWM_SIGNALS_MODES                                                              \
        (((uint32)(TimerPWM_PWM_SWITCH_SIGNAL_MODE  << TimerPWM_CAPTURE_SHIFT))         |\
         ((uint32)(TimerPWM_PWM_COUNT_SIGNAL_MODE   << TimerPWM_COUNT_SHIFT))           |\
         ((uint32)(TimerPWM_PWM_RELOAD_SIGNAL_MODE  << TimerPWM_RELOAD_SHIFT))          |\
         ((uint32)(TimerPWM_PWM_STOP_SIGNAL_MODE    << TimerPWM_STOP_SHIFT))            |\
         ((uint32)(TimerPWM_PWM_START_SIGNAL_MODE   << TimerPWM_START_SHIFT)))

#define TimerPWM_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(TimerPWM_TC_CAPTURE_SIGNAL_MODE  << TimerPWM_CAPTURE_SHIFT))         |\
         ((uint32)(TimerPWM_TC_COUNT_SIGNAL_MODE    << TimerPWM_COUNT_SHIFT))           |\
         ((uint32)(TimerPWM_TC_RELOAD_SIGNAL_MODE   << TimerPWM_RELOAD_SHIFT))          |\
         ((uint32)(TimerPWM_TC_STOP_SIGNAL_MODE     << TimerPWM_STOP_SHIFT))            |\
         ((uint32)(TimerPWM_TC_START_SIGNAL_MODE    << TimerPWM_START_SHIFT)))
        
#define TimerPWM_TIMER_UPDOWN_CNT_USED                                                          \
                ((TimerPWM__COUNT_UPDOWN0 == TimerPWM_TC_COUNTER_MODE)                  ||\
                 (TimerPWM__COUNT_UPDOWN1 == TimerPWM_TC_COUNTER_MODE))

#define TimerPWM_PWM_UPDOWN_CNT_USED                                                            \
                ((TimerPWM__CENTER == TimerPWM_PWM_ALIGN)                               ||\
                 (TimerPWM__ASYMMETRIC == TimerPWM_PWM_ALIGN))               
        
#define TimerPWM_PWM_PR_INIT_VALUE              (1u)
#define TimerPWM_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_TimerPWM_H */

/* [] END OF FILE */
